@@ -6,7 +6,7 @@
 # <sanvila@ctv.es> and octave by Dirk Eddelbuettel <edd@debian.org>.
 
 FLAVOR=$1
-PACKAGE=netcdf-ifc8.1
+PACKAGE=netcdf-ifc9
 
 if [ ${FLAVOR} = emacs ]; then exit 0; fi
 
