@@ -3,7 +3,7 @@
  *      See netcdf/COPYRIGHT file for copying and redistribution conditions.
  */
 
-/* $Id: fort-v2compat.c,v 1.23 2004/11/16 21:51:17 russ Exp $ */
+/* $Id: fort-v2compat.c,v 1.25 2006/01/28 20:01:19 ed Exp $ */
 
 /*
  *  Source for netCDF FORTRAN jacket library.
@@ -26,7 +26,7 @@
 
 /* LINTLIBRARY */
 
-#include	"ncconfig.h"
+#include	<config.h>
 #include	<ctype.h>
 #include        <string.h>
 #include	<stdlib.h>
@@ -68,13 +68,11 @@
 static ptrdiff_t*
 f2c_v2imap(int ncid, int varid, const int* fimap, ptrdiff_t* cimap)
 {
-    int		status;
     int		rank;
     nc_type	datatype;
 
-    if ((status = nc_inq_vartype(ncid, varid, &datatype)) != NC_NOERR ||
-	(status = nc_inq_varndims(ncid, varid, &rank)) != NC_NOERR ||
-	rank <= 0)
+    if (nc_inq_vartype(ncid, varid, &datatype) ||
+	nc_inq_varndims(ncid, varid, &rank) || rank <= 0)
     {
 	return NULL;
     }
